<?php
/**
 * White xmas functions and definitions
 *
 * @package white-xmas
 */

if ( ! function_exists( 'whitexmas_setup' ) ) {
	function whitexmas_setup() {
		/**
		 * Set the content width based on the theme's design and stylesheet.
		 */
		global $content_width;
		if ( ! isset( $content_width ) ) {
			$content_width = 640; /* pixels */
		}

		load_theme_textdomain( 'white-xmas', get_template_directory() . '/languages' );

		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'custom-logo' );
		add_theme_support( 'customize-selective-refresh-widgets' );
		add_theme_support( 'wp-block-styles' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'primary' => __( 'Primary Menu', 'white-xmas' ),
			)
		);

		// Setup the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'whitexmas_custom_background_args',
				array(
					'default-color' => 'efefef',
					'default-image' => '',
				)
			)
		);

		$whitexmas_ch = array(
			'default-image'          => get_template_directory_uri() . '/img/bg.png',
			'random-default'         => false,
			'width'                  => 769,
			'height'                 => 208,
			'flex-height'            => true,
			'flex-width'             => true,
			'uploads'                => true,
			'header-text'            => true,
			'default-text-color'     => '000000',
			'wp-head-callback'       => 'whitexmas_customize_css',
		);

		add_theme_support( 'custom-header', $whitexmas_ch );
		add_editor_style();

	}
}
add_action( 'after_setup_theme', 'whitexmas_setup' );

/**
 * Custom CSS
 */
function whitexmas_customize_css() {
	echo '<style type="text/css">
	.site-title a, .site-description { color: #' . esc_attr( get_header_textcolor() ) . ';}';

	$whitexmas_header_image = get_header_image();
	if ( $whitexmas_header_image ) {
		echo '.site-header {background: #ffffff url(' . esc_url( get_header_image() ) . ');}';
	}

	if ( get_theme_mod( 'whitexmas_hide_deer' ) ) {
		echo '.site-branding {background: none; }';
		echo '.site-info {background: none; }';
	}

	if ( ! display_header_text() ) {
		echo '.menu {width: 65%; margin-top: 25px;}';
		echo '@media screen and (max-width: 1024px) {
				.menu {width: 90%; margin-top: 25px;}
		}';
	}

	echo '</style>';
}
add_action( 'wp_head', 'whitexmas_customize_css' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function whitexmas_widgets_init() {
	register_sidebar(
		array(
			'name'          => __( 'Sidebar', 'white-xmas' ),
			'id'            => 'sidebar-1',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h2 class="widgettitle">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'whitexmas_widgets_init' );


/**
 * Enqueue scripts and styles.
 */
function whitexmas_scripts() {
	wp_enqueue_style( 'whitexmas-style', get_stylesheet_uri() );
	wp_enqueue_style( 'whitexmas-font', '//fonts.googleapis.com/css?family=Sofia|Tangerine' );
	wp_enqueue_script( 'whitexmas-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_enqueue_script( 'whitexmas-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'whitexmas_scripts' );

/* Add title and class to read more links */
add_filter( 'get_the_excerpt', 'whitexmas_custom_excerpt_more', 100 );
add_filter( 'excerpt_more', 'whitexmas_excerpt_more', 100 );
add_filter( 'the_content_more_link', 'whitexmas_content_more', 100 );

function whitexmas_continue_reading( $id ) {
	return '<a href="' . esc_url( get_permalink( $id ) ) . '" class="more-link">' . __( 'Read more: ', 'white-xmas' ) . esc_html( get_the_title( $id ) ) . '</a>';
}

function whitexmas_content_more( $more ) {
	global $id;
	return whitexmas_continue_reading( $id );
}

function whitexmas_excerpt_more( $more ) {
	if ( is_admin() ) {
		return $more;
	} else {
		global $id;
		return '... ' . whitexmas_continue_reading( $id );
	}
}

function whitexmas_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		global $id;
		$output .= ' ' . whitexmas_continue_reading( $id );
	}
	return $output;
}

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Add a pingback url.
 */
function whitexmas_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">' . "\n", get_bloginfo( 'pingback_url' ) );
	}
}
add_action( 'wp_head', 'whitexmas_pingback_header' );

/**
 * Add a title to posts that are missing titles.
 */
function whitexmas_post_title( $title ) {
	if ( '' === $title ) {
		return __( '(Untitled)', 'white-xmas' );
	} else {
		return $title;
	}
}
add_filter( 'the_title', 'whitexmas_post_title' );

/**
 * Breadcrumbs
 */
function whitexmas_breadcrumbs() {
	if ( ! get_theme_mod( 'whitexmas_hide_breadcrumbs' ) ) {
		?>
		<div class="crumbs"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php esc_html_e( 'Home', 'white-xmas' ); ?></a>
		<?php
		if ( count( get_the_category() ) ) {
			$whitexmas_category = get_the_category();
			if ( $whitexmas_category[0] ) {
				echo ' / <a href="' . esc_url( get_category_link( $whitexmas_category[0]->term_id ) ) . '">'
				. esc_html( $whitexmas_category[0]->cat_name ) . '</a>';
			}
		}
		echo ' / ';
		?>
		<?php the_title(); ?>
		</div>
		<?php
	}
}
